@@ -29,6 +29,7 @@
 
 #include "calls-contacts-provider.h"
 #include "calls-best-match.h"
+#include "calls-settings.h"
 
 #include <gee-0.8/gee.h>
 #include <folks/folks.h>
@@ -48,16 +49,14 @@
  */
 
 
-typedef struct
-{
-  GeeIterator           *iter;
-  IdleCallback           callback;
-  gpointer               user_data;
+typedef struct {
+  GeeIterator *iter;
+  IdleCallback callback;
+  gpointer     user_data;
 } IdleData;
 
 
-struct _CallsContactsProvider
-{
+struct _CallsContactsProvider {
   GObject                    parent_instance;
 
   FolksIndividualAggregator *folks_aggregator;
@@ -74,7 +73,6 @@ G_DEFINE_TYPE (CallsContactsProvider, calls_contacts_provider, G_TYPE_OBJECT)
 
 enum {
   PROP_0,
-  PROP_SETTINGS,
   PROP_CAN_ADD_CONTACTS,
   PROP_LAST_PROP
 };
@@ -215,12 +213,13 @@ on_contacts_actions_updated (CallsContactsProvider *self)
 
 
 static void
-on_contacts_appeared (GDBusConnection    *connection,
-                      const char         *name,
-                      const char         *owner_name,
-                      gpointer            user_data)
+on_contacts_appeared (GDBusConnection *connection,
+                      const char      *name,
+                      const char      *owner_name,
+                      gpointer         user_data)
 {
   CallsContactsProvider *self;
+
   g_autoptr (GError) error = NULL;
 
   g_assert (CALLS_IS_CONTACTS_PROVIDER (user_data));
@@ -240,26 +239,6 @@ on_contacts_appeared (GDBusConnection    *connection,
 }
 
 
-static void
-calls_contacts_provider_set_property (GObject      *object,
-                                      guint         property_id,
-                                      const GValue *value,
-                                      GParamSpec   *pspec)
-{
-  CallsContactsProvider *self = CALLS_CONTACTS_PROVIDER (object);
-
-  switch (property_id) {
-  case PROP_SETTINGS:
-    self->settings = g_value_dup_object (value);
-    break;
-
-  default:
-    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-    break;
-  }
-}
-
-
 static void
 calls_contacts_provider_get_property (GObject    *object,
                                       guint       property_id,
@@ -288,7 +267,6 @@ calls_contacts_provider_finalize (GObject *object)
   g_clear_handle_id (&self->bus_watch_id, g_bus_unwatch_name);
   g_clear_object (&self->contacts_action_group);
   g_clear_object (&self->folks_aggregator);
-  g_clear_object (&self->settings);
   g_clear_pointer (&self->best_matches, g_hash_table_unref);
 
   G_OBJECT_CLASS (calls_contacts_provider_parent_class)->finalize (object);
@@ -298,10 +276,9 @@ calls_contacts_provider_finalize (GObject *object)
 static void
 calls_contacts_provider_class_init (CallsContactsProviderClass *klass)
 {
-  GObjectClass *object_class  = G_OBJECT_CLASS (klass);
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->get_property = calls_contacts_provider_get_property;
-  object_class->set_property = calls_contacts_provider_set_property;
   object_class->finalize = calls_contacts_provider_finalize;
 
   /**
@@ -313,14 +290,14 @@ calls_contacts_provider_class_init (CallsContactsProviderClass *klass)
    * having been added.
    */
   signals[SIGNAL_ADDED] =
-   g_signal_new ("added",
-                 G_TYPE_FROM_CLASS (klass),
-                 G_SIGNAL_RUN_LAST,
-                 0,
-                 NULL, NULL, NULL,
-                 G_TYPE_NONE,
-                 1,
-                 FOLKS_TYPE_INDIVIDUAL);
+    g_signal_new ("added",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL, NULL,
+                  G_TYPE_NONE,
+                  1,
+                  FOLKS_TYPE_INDIVIDUAL);
   /**
    * CallsContactsProvider::removed:
    * @self: The #CallsContactsProvider instance
@@ -330,28 +307,14 @@ calls_contacts_provider_class_init (CallsContactsProviderClass *klass)
    * having been removed.
    */
   signals[SIGNAL_REMOVED] =
-   g_signal_new ("removed",
-                 G_TYPE_FROM_CLASS (klass),
-                 G_SIGNAL_RUN_LAST,
-                 0,
-                 NULL, NULL, NULL,
-                 G_TYPE_NONE,
-                 1,
-                 FOLKS_TYPE_INDIVIDUAL);
-
-  /**
-   * CallsContactsProvider::settings:
-   *
-   * The settings are used to get the country code
-   * which is used for contact lookups.
-   */
-  props[PROP_SETTINGS] =
-    g_param_spec_object ("settings",
-                         "settings",
-                         "The settings object to use",
-                         CALLS_TYPE_SETTINGS,
-                         G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY |
-                         G_PARAM_STATIC_STRINGS);
+    g_signal_new ("removed",
+                  G_TYPE_FROM_CLASS (klass),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL, NULL,
+                  G_TYPE_NONE,
+                  1,
+                  FOLKS_TYPE_INDIVIDUAL);
 
   /**
    * CallsContactsProvider::can-add-contacts:
@@ -373,6 +336,8 @@ static void
 calls_contacts_provider_init (CallsContactsProvider *self)
 {
   g_autoptr (GeeCollection) individuals = NULL;
+
+  self->settings = calls_settings_get_default ();
   self->folks_aggregator = folks_individual_aggregator_dup ();
 
   individuals = calls_contacts_provider_get_individuals (self);
@@ -405,9 +370,9 @@ calls_contacts_provider_init (CallsContactsProvider *self)
 
 
 CallsContactsProvider *
-calls_contacts_provider_new (CallsSettings *settings)
+calls_contacts_provider_new (void)
 {
-  return g_object_new (CALLS_TYPE_CONTACTS_PROVIDER, "settings", settings, NULL);
+  return g_object_new (CALLS_TYPE_CONTACTS_PROVIDER, NULL);
 }
 
 
@@ -481,6 +446,7 @@ calls_contacts_provider_consume_iter_on_idle (GeeIterator *iter,
                                               gpointer     user_data)
 {
   IdleData *data = g_new (IdleData, 1);
+
   data->iter = iter;
   data->user_data = user_data;
   data->callback = callback;
